==> landtax-1.0.0-20161009.022418-24-sources.jar: cn/gtmap/landtax/model/query/GtSwTzQuery.java <==
package cn.gtmap.landtax.model.query;

import java.math.BigDecimal;

/**
 * .
 * <p/>
 * 税务国土通过djh关联
 * @author yang
 * @version V1.0, 14-7-7
 */
public class GtSwTzQuery {
    private String gtbdId;

    //税务信息
    private String tdId;
    private String fcId;
    private  String glbm;
    private  String djh;
    private String dbh;
    private String nsrmc;
    private String zgjgMc;
    private String zgkgMc;
    private String glyMc;
    private String sgyMc;
    private BigDecimal tdnynse;
    private BigDecimal nynseTd;
    private BigDecimal fcnynse;
    private BigDecimal nynseFc;
    private String bdtype;

    //国土信息
    private String tdzl;
    private String tdytMc;
    private String tdytDm;
    private String qlrmc;
    private String ppzt;
    private String tdzh;
    private BigDecimal scmj;

    private String isxf;
    private String excelBegin;
    private String excelEnd;

    private String activityDefinitionId;
    private String ids;

    private String statue;

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public BigDecimal getScmj() {
        return scmj;
    }

    public void setScmj(BigDecimal scmj) {
        this.scmj = scmj;
    }

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    public String getTdytMc() {
        return tdytMc;
    }

    public void setTdytMc(String tdytMc) {
        this.tdytMc = tdytMc;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getPpzt() {
        return ppzt;
    }

    public void setPpzt(String ppzt) {
        this.ppzt = ppzt;
    }

    public String getGlbm() {
        return glbm;
    }

    public void setGlbm(String glbm) {
        this.glbm = glbm;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getDbh() {
        return dbh;
    }

    public void setDbh(String dbh) {
        this.dbh = dbh;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getZgjgMc() {
        return zgjgMc;
    }

    public void setZgjgMc(String zgjgMc) {
        this.zgjgMc = zgjgMc;
    }

    public String getGlyMc() {
        return glyMc;
    }

    public void setGlyMc(String glyMc) {
        this.glyMc = glyMc;
    }

    public BigDecimal getTdnynse() {
        return tdnynse;
    }

    public void setTdnynse(BigDecimal tdnynse) {
        this.tdnynse = tdnynse;
    }

    public BigDecimal getFcnynse() {
        return fcnynse;
    }

    public void setFcnynse(BigDecimal fcnynse) {
        this.fcnynse = fcnynse;
    }

    public String getBdtype() {
        return bdtype;
    }

    public void setBdtype(String bdtype) {
        this.bdtype = bdtype;
    }

    public String getTdytDm() {
        return tdytDm;
    }

    public void setTdytDm(String tdytDm) {
        this.tdytDm = tdytDm;
    }

    public String getTdId() {
        return tdId;
    }

    public void setTdId(String tdId) {
        this.tdId = tdId;
    }

    public String getFcId() {
        return fcId;
    }

    public void setFcId(String fcId) {
        this.fcId = fcId;
    }

    public String getGtbdId() {
        return gtbdId;
    }

    public void setGtbdId(String gtbdId) {
        this.gtbdId = gtbdId;
    }

    public String getZgkgMc() {
        return zgkgMc;
    }

    public void setZgkgMc(String zgkgMc) {
        this.zgkgMc = zgkgMc;
    }

    public String getSgyMc() {
        return sgyMc;
    }

    public void setSgyMc(String sgyMc) {
        this.sgyMc = sgyMc;
    }

    public BigDecimal getNynseTd() {
        return nynseTd;
    }

    public void setNynseTd(BigDecimal nynseTd) {
        this.nynseTd = nynseTd;
    }

    public BigDecimal getNynseFc() {
        return nynseFc;
    }

    public void setNynseFc(BigDecimal nynseFc) {
        this.nynseFc = nynseFc;
    }

    public String getIsxf() {
        return isxf;
    }

    public void setIsxf(String isxf) {
        this.isxf = isxf;
    }

    public String getExcelBegin() {
        return excelBegin;
    }

    public void setExcelBegin(String excelBegin) {
        this.excelBegin = excelBegin;
    }

    public String getExcelEnd() {
        return excelEnd;
    }

    public void setExcelEnd(String excelEnd) {
        this.excelEnd = excelEnd;
    }

    public String getActivityDefinitionId() {
        return activityDefinitionId;
    }

    public void setActivityDefinitionId(String activityDefinitionId) {
        this.activityDefinitionId = activityDefinitionId;
    }

    public String getIds() {
        return ids;
    }

    public void setIds(String ids) {
        this.ids = ids;
    }

    public String getStatue() {
        return statue;
    }

    public void setStatue(String statue) {
        this.statue = statue;
    }
}

==> landtax-1.0.0-20180601.023313-26-sources.jar: cn/gtmap/landtax/model/query/GtSwTzQuery.java <==
package cn.gtmap.landtax.model.query;

import java.math.BigDecimal;

/**
 * .
 * <p/>
 * 税务国土通过djh关联
 * @author yang
 * @version V1.0, 14-7-7
 */
public class GtSwTzQuery {
    private String gtbdId;

    //税务信息
    private String tdId;
    private String fcId;
    private  String glbm;
    private  String djh;
    private String dbh;
    private String nsrmc;
    private String zgjgMc;
    private String zgkgMc;
    private String glyMc;
    private String sgyMc;
    private BigDecimal tdnynse;
    private BigDecimal nynseTd;
    private BigDecimal fcnynse;
    private BigDecimal nynseFc;
    private String bdtype;
    private String nsrsbh;


    //国土信息
    private String tdzl;
    private String tdytMc;
    private String tdytDm;
    private String qlrmc;
    private String ppzt;
    private String tdzh;
    private BigDecimal scmj;

    private String isxf;
    private String excelBegin;
    private String excelEnd;

    private String activityDefinitionId;
    private String ids;

    private String statue;

    private String qx;

    private String zgkgDm;

    private String jdDm;
    public String getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(String nsrsbh) {
        this.nsrsbh = nsrsbh;
    }


    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public BigDecimal getScmj() {
        return scmj;
    }

    public void setScmj(BigDecimal scmj) {
        this.scmj = scmj;
    }

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    public String getTdytMc() {
        return tdytMc;
    }

    public void setTdytMc(String tdytMc) {
        this.tdytMc = tdytMc;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getPpzt() {
        return ppzt;
    }

    public void setPpzt(String ppzt) {
        this.ppzt = ppzt;
    }

    public String getGlbm() {
        return glbm;
    }

    public void setGlbm(String glbm) {
        this.glbm = glbm;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getDbh() {
        return dbh;
    }

    public void setDbh(String dbh) {
        this.dbh = dbh;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getZgjgMc() {
        return zgjgMc;
    }

    public void setZgjgMc(String zgjgMc) {
        this.zgjgMc = zgjgMc;
    }

    public String getGlyMc() {
        return glyMc;
    }

    public void setGlyMc(String glyMc) {
        this.glyMc = glyMc;
    }

    public BigDecimal getTdnynse() {
        return tdnynse;
    }

    public void setTdnynse(BigDecimal tdnynse) {
        this.tdnynse = tdnynse;
    }

    public BigDecimal getFcnynse() {
        return fcnynse;
    }

    public void setFcnynse(BigDecimal fcnynse) {
        this.fcnynse = fcnynse;
    }

    public String getBdtype() {
        return bdtype;
    }

    public void setBdtype(String bdtype) {
        this.bdtype = bdtype;
    }

    public String getTdytDm() {
        return tdytDm;
    }

    public void setTdytDm(String tdytDm) {
        this.tdytDm = tdytDm;
    }

    public String getTdId() {
        return tdId;
    }

    public void setTdId(String tdId) {
        this.tdId = tdId;
    }

    public String getFcId() {
        return fcId;
    }

    public void setFcId(String fcId) {
        this.fcId = fcId;
    }

    public String getGtbdId() {
        return gtbdId;
    }

    public void setGtbdId(String gtbdId) {
        this.gtbdId = gtbdId;
    }

    public String getZgkgMc() {
        return zgkgMc;
    }

    public void setZgkgMc(String zgkgMc) {
        this.zgkgMc = zgkgMc;
    }

    public String getSgyMc() {
        return sgyMc;
    }

    public void setSgyMc(String sgyMc) {
        this.sgyMc = sgyMc;
    }

    public BigDecimal getNynseTd() {
        return nynseTd;
    }

    public void setNynseTd(BigDecimal nynseTd) {
        this.nynseTd = nynseTd;
    }

    public BigDecimal getNynseFc() {
        return nynseFc;
    }

    public void setNynseFc(BigDecimal nynseFc) {
        this.nynseFc = nynseFc;
    }

    public String getIsxf() {
        return isxf;
    }

    public void setIsxf(String isxf) {
        this.isxf = isxf;
    }

    public String getExcelBegin() {
        return excelBegin;
    }

    public void setExcelBegin(String excelBegin) {
        this.excelBegin = excelBegin;
    }

    public String getExcelEnd() {
        return excelEnd;
    }

    public void setExcelEnd(String excelEnd) {
        this.excelEnd = excelEnd;
    }

    public String getActivityDefinitionId() {
        return activityDefinitionId;
    }

    public void setActivityDefinitionId(String activityDefinitionId) {
        this.activityDefinitionId = activityDefinitionId;
    }

    public String getIds() {
        return ids;
    }

    public void setIds(String ids) {
        this.ids = ids;
    }

    public String getStatue() {
        return statue;
    }

    public void setStatue(String statue) {
        this.statue = statue;
    }

    public String getQx() {
        return qx;
    }

    public void setQx(String qx) {
        this.qx = qx;
    }

    public String getZgkgDm() {
        return zgkgDm;
    }

    public void setZgkgDm(String zgkgDm) {
        this.zgkgDm = zgkgDm;
    }

    public String getJdDm() {
        return jdDm;
    }

    public void setJdDm(String jdDm) {
        this.jdDm = jdDm;
    }
}
